==> sapdb-source-7.3.00.48.tgz: V73_00_48/SAPDB_ORG/sys/src/eo/veo573.cpp <==
/****************************************************************************

  module      : veo573.cpp

  -------------------------------------------------------------------------

  responsible : RaymondR

  special area: Global scope new and delete.
  description : Global scope new and delete.


  last changed: 1999-12-16  16:29
  see also    : 

  -------------------------------------------------------------------------

  copyright:    Copyright by SAP AG, 1999



    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

*****************************************************************************/



/*===========================================================================*
 *  INCLUDES                                                                 *
 *===========================================================================*/

#include "geo570.h"
#include "geo573.h"

#if defined(AIX)
# include <new>
#endif

/*===========================================================================*
 *  DEFINES                                                                  *
 *===========================================================================*/



/*===========================================================================*
 *  MACROS                                                                   *
 *===========================================================================*/



/*===========================================================================*
 *  LOCAL CLASSES, STRUCTURES, TYPES, UNIONS ...                             *
 *===========================================================================*/



/*===========================================================================*
 *  STATIC/INLINE FUNCTIONS (PROTOTYPES)                                     *
 *===========================================================================*/



/*===========================================================================*
 *  METHODS                                                                  *
 *===========================================================================*/

#if defined(SUN) || defined(AIX)
 void *operator new      ( size_t    Size )  throw (std::bad_alloc)
                                             { return teo570_GlobalAlloc::eo570_Allocate(Size,__FILE__,__LINE__); };
#else
 void *operator new      ( size_t    Size )  { return teo570_GlobalAlloc::eo570_Allocate(Size,__FILE__,__LINE__); };
#endif

#if defined(AIX)
  void operator  delete ( void *    Buffer ) throw()
                                            { if ( Buffer != NULL) teo570_GlobalAlloc::eo570_Deallocate(Buffer,__FILE__,__LINE__); };
#else
  void operator  delete ( void *    Buffer, 
                          size_t    Size )  { if ( Buffer != NULL) teo570_GlobalAlloc::eo570_Deallocate(Buffer,__FILE__,__LINE__); };
#endif 

#if (defined(_WIN32) && _MSC_VER > 1100)
  void operator  delete ( void *    Buffer ){ if ( Buffer != NULL) teo570_GlobalAlloc::eo570_Deallocate(Buffer,__FILE__,__LINE__); };
#endif 

#if !defined ( _IBMR2 ) && !defined ( SUN )
  void *operator new[]  ( size_t    Size )  { return teo570_GlobalAlloc::eo570_Allocate(Size,__FILE__,__LINE__); };
#endif


/*===========================================================================*
 *  END OF CODE                                                              *
 *===========================================================================*/

==> sapdb-source-7.4.03.32.tgz: V74_03_32/SAPDB_ORG/sys/src/eo/veo573.cpp <==
/****************************************************************************

  module      : veo573.cpp

  -------------------------------------------------------------------------

  responsible : RaymondR

  special area: Global scope new and delete.
  description : Global scope new and delete.


  last changed: 1999-12-16  16:29
  see also    : 

  -------------------------------------------------------------------------

  copyright:    Copyright by SAP AG, 1999



    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

*****************************************************************************/



/*===========================================================================*
 *  INCLUDES                                                                 *
 *===========================================================================*/

#include "geo570.h"
#include "geo573.h"

#if defined(AIX)
# include <new>
#endif

/*===========================================================================*
 *  DEFINES                                                                  *
 *===========================================================================*/



/*===========================================================================*
 *  MACROS                                                                   *
 *===========================================================================*/



/*===========================================================================*
 *  LOCAL CLASSES, STRUCTURES, TYPES, UNIONS ...                             *
 *===========================================================================*/



/*===========================================================================*
 *  STATIC/INLINE FUNCTIONS (PROTOTYPES)                                     *
 *===========================================================================*/



/*===========================================================================*
 *  METHODS                                                                  *
 *===========================================================================*/

void *operator new ( size_t    Size ) THROW_NEW_GEO573
{ 
  return teo570_GlobalAlloc::eo570_Allocate(Size,__FILE__,__LINE__); 
};

void operator delete ( void * Buffer ) THROW_DELETE_GEO573
{
  if ( Buffer != NULL) teo570_GlobalAlloc::eo570_Deallocate(Buffer,__FILE__,__LINE__);
};

void *operator new[] ( size_t Size ) THROW_NEW_GEO573
{
  return teo570_GlobalAlloc::eo570_Allocate(Size,__FILE__,__LINE__); 
}

void operator delete[]  ( void * Buffer ) THROW_DELETE_GEO573
{
  if ( Buffer != NULL) teo570_GlobalAlloc::eo570_Deallocate(Buffer,__FILE__,__LINE__);
}

#if defined (_WIN32) 
void *__cdecl operator new(size_t Size, const std::nothrow_t& ) throw()
{
  char *p;
  try 
  {
      p = (char *)teo570_GlobalAlloc::eo570_Allocate(Size,__FILE__,__LINE__); 
  }
  catch (std::bad_alloc)
  {
      p = NULL;
  }
 return p;
} 

void *__cdecl operator new[](size_t Size, const std::nothrow_t& ) throw()
{
  char *p;
  try 
  {
      p = (char *)teo570_GlobalAlloc::eo570_Allocate(Size,__FILE__,__LINE__); 
  }
  catch (std::bad_alloc)
  {
      p = NULL;
  }
 return p;
} 

void __cdecl operator delete( void * Buffer, const std::nothrow_t& ) throw()
{
  if ( Buffer != NULL) teo570_GlobalAlloc::eo570_Deallocate(Buffer,__FILE__,__LINE__);
}

void __cdecl operator delete[]( void * Buffer, const std::nothrow_t& ) throw()
{
  if ( Buffer != NULL) teo570_GlobalAlloc::eo570_Deallocate(Buffer,__FILE__,__LINE__);
}
#endif

/*===========================================================================*
 *  END OF CODE                                                              *
 *===========================================================================*/
